#include "cvidef.h"

/*= <KEITHLEY 24xx> =========================================================*/
/* LabWindows/CVI Instrument Driver                                      	 */
/* Original Release : 10/03/2000                                             */
/* By: Alain Laine                                                           */
/*     PH. 33/1/64/53/20/26   												 */
/*     Fax : 33/1/60/11/77/26     											 */
/*     Email : Laine_alain@keithley.com        				                 */
/* Modification History: 	                                                 */
/* First Release Version 1.00  Mar. 2001  by John Ryland					 */
/*																			 */
/*===========================================================================*/

#ifndef __KE24XX_HEADER
#define __KE24XX_HEADER

#include "vpptype.h"

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Specific constants to make the user code clearer =============*/
/*****************************************************************************/
/*																			 */
/* We recommend using these defined values when programming the 24xx    	 */
/* This will make the code easier to read									 */
/*																			 */
/*****************************************************************************/

//extern ViInt32		nKe24xx_ErrorCode;
//extern ViChar	    szKe24xx_ErrorMessage[256];
//extern ViInt32		nKe24xx_Model;

#define MAX_INSTRUMENTS						50
#define KE24XX_MAX_RANGES					12

// Setups

#define KE24XX_BENCH_SETUP					-2
#define KE24XX_REMOTE_SETUP					-1
#define KE24XX_USER_SETUP_0					0
#define KE24XX_USER_SETUP_1					1
#define KE24XX_USER_SETUP_2					2
#define KE24XX_USER_SETUP_3					3
#define KE24XX_USER_SETUP_4					4

// SYSTEM DEFINES

#define KE24XX_GUARD_CABLE					0
#define KE24XX_GUARD_OHMS					1

#define KE24XX_LFREQ_AUTO					0
#define KE24XX_LFREQ_50						50
#define KE24XX_LFREQ_60						60

#define KE24XX_USE_FRONT_TERMINALS			0
#define KE24XX_USE_REAR_TERMINALS			1

#define KE24XX_RCMODE_SINGLE				0
#define KE24XX_RCMODE_MULTIPLE				1

// Register names that can be addressed for R/W operations

#define KE24XX_REG_SRE				0	   // Service Request Enable
#define KE24XX_REG_ESE				1	   // Standard Event Enable
#define KE24XX_REG_QUES_ENAB		2	   // Questionable Event Enable Register
#define KE24XX_REG_MEAS_ENAB		3	   // Measurement Event Enable Register
#define KE24XX_REG_OPER_ENAB		4	   // Operation Event Enable Register

// Registers for read only operations

#define KE24XX_REG_STB				5		// Status byte register (=SPE)
#define KE24XX_REG_ESE_EVENT		6		// Standard Event 
#define KE24XX_REG_QUES_COND		7		// Questionable condition
#define KE24XX_REG_MEAS_COND		8		// Measurement condition
#define KE24XX_REG_OPER_COND		9		// Questionable condition
#define KE24XX_REG_QUES_EVENT		10		// Operation Event
#define KE24XX_REG_MEAS_EVENT		11		// Measurement Event
#define KE24XX_REG_OPER_EVENT		12		// Operation Event

// SRQ Condition : See documentation

#define KE24XX_NO_SRQ			     			0x00000000    
#define KE24XX_SRQ_ON_ERROR_AVAILABLE			0x00000001    
#define KE24XX_SRQ_ON_MESSAGE_AVAILABLE			0x00000002
#define KE24XX_SRQ_ON_OPERATION_COMPLETE		0x00000004	
#define KE24XX_SRQ_ON_QUERY_ERROR  				0x00000008	  
#define KE24XX_SRQ_ON_DEVICE_ERROR				0x00000010	  
#define KE24XX_SRQ_ON_EXECUTION_ERROR   		0x00000020	  
#define KE24XX_SRQ_ON_COMMAND_ERROR				0x00000040	  
#define KE24XX_SRQ_ON_USER_REQUEST		 		0x00000080	  
#define KE24XX_SRQ_ON_POWER_ON			 		0x00000100	  
#define KE24XX_SRQ_ON_CALIBRATION_SUMMARY		0x00000200	  
#define KE24XX_SRQ_ON_COMMAND_WARNING	 		0x00000400	  
#define KE24XX_SRQ_ON_CALIBRATING		 		0x00000800	  
#define KE24XX_SRQ_ON_SWEEPING			 		0x00001000	  
#define KE24XX_SRQ_ON_WAITING_TRIGGER	 		0x00002000	  
#define KE24XX_SRQ_ON_WAITING_ARM		 		0x00004000	  
#define KE24XX_SRQ_ON_IDLE				 		0x00008000	  
#define KE24XX_SRQ_ON_LIMIT1_FAIL				0x00010000	  
#define KE24XX_SRQ_ON_LOWLIMIT2_FAIL			0x00020000	  
#define KE24XX_SRQ_ON_HIGHLIMIT2_FAIL			0x00040000	  
#define KE24XX_SRQ_ON_LOWLIMIT3_FAIL			0x00080000	  
#define KE24XX_SRQ_ON_HIGHLIMIT3_FAIL			0x00100000	  
#define KE24XX_SRQ_ON_LIMITS_PASS				0x00200000	  
#define KE24XX_SRQ_ON_READING_AVAILABLE			0x00400000	  
#define KE24XX_SRQ_ON_READING_OVERFLOW			0x00800000	  
#define KE24XX_SRQ_ON_BUFFER_AVAILABLE			0x01000000	  
#define KE24XX_SRQ_ON_BUFFER_FULL				0x02000000	  
#define KE24XX_SRQ_ON_CONTACT_CHECK				0x04000000	  
#define KE24XX_SRQ_ON_INTERLOCK_ASSERTED		0x08000000	  
#define KE24XX_SRQ_ON_OVER_TEMPERATURE			0x10000000	  
#define KE24XX_SRQ_ON_OVER_VOLTAGE_PROTECTION	0x20000000	  
#define KE24XX_SRQ_ON_COMPLIANCE				0x80000000	

// Display Windows

#define KE24XX_DISPLAY_TOP_LINE					1
#define KE24XX_DISPLAY_BOTTOM_LINE				2

#define KE24XX_DISPLAY_NORMAL_MODE				0
#define KE24XX_DISPLAY_MESSAGE_MODE				1

#define KE24XX_DISPLAY_3_5_DIGITS				4
#define KE24XX_DISPLAY_4_5_DIGITS				5
#define KE24XX_DISPLAY_5_5_DIGITS				6
#define KE24XX_DISPLAY_6_5_DIGITS				7

// Source Output Off Modes

#define KE24XX_OFF_MODE_HIMP					0
#define KE24XX_OFF_MODE_NORMAL					1
#define KE24XX_OFF_MODE_ZERO					2
#define KE24XX_OFF_MODE_GUARD					3

// Filter type

#define KE24XX_REPEAT_FILTER					1
#define KE24XX_MOVING_FILTER					0

// Ohms Mode

#define KE24XX_AUTO_OHMS						1
#define KE24XX_MANUAL_OHMS						0

// Ranges

#define KE24XX_AUTO_RANGE						0

#define KE24XX_200M_V_RANGE						1
#define KE24XX_2_V_RANGE						2
#define KE24XX_10_V_RANGE						3
#define KE24XX_20_V_RANGE						4
#define KE24XX_40_V_RANGE						5
#define KE24XX_60_V_RANGE						6
#define KE24XX_100_V_RANGE						7
#define KE24XX_200_V_RANGE						8
#define KE24XX_1000_V_RANGE						9

#define KE24XX_1U_A_RANGE						1
#define KE24XX_10U_A_RANGE						2
#define KE24XX_100U_A_RANGE						3
#define KE24XX_1M_A_RANGE						4
#define KE24XX_10M_A_RANGE						5
#define KE24XX_20M_A_RANGE						6
#define KE24XX_100M_A_RANGE						7
#define KE24XX_1_A_RANGE						8
#define KE24XX_3_A_RANGE						9
#define KE24XX_5_A_RANGE						10
#define KE24XX_10_A_RANGE						11

#define KE24XX_200_mOHMS_RANGE					1
#define KE24XX_2_OHMS_RANGE						2
#define KE24XX_20_OHMS_RANGE					3
#define KE24XX_200_OHMS_RANGE					4
#define KE24XX_2K_OHMS_RANGE					5
#define KE24XX_20K_OHMS_RANGE					6
#define KE24XX_200K_OHMS_RANGE					7
#define KE24XX_2M_OHMS_RANGE					8
#define KE24XX_20M_OHMS_RANGE					9
#define KE24XX_200M_OHMS_RANGE					10

// Source modes, functions and shapes

#define KE24XX_SOURCE_ACTUAL_FUNCTION			-1
#define KE24XX_SOURCE_VOLTAGE_FUNCTION			0
#define KE24XX_SOURCE_CURRENT_FUNCTION			1

// When to set amplitude for fixed source
#define KE24XX_SOURCE_LEVEL_IMMEDIATE		    0
#define KE24XX_SOURCE_LEVEL_TRIGGERED    		1

#define KE24XX_SOURCE_FIXED_MODE				0
#define KE24XX_SOURCE_SWEEP_MODE				1
#define KE24XX_SOURCE_LIST_MODE					2

#define KE24XX_SOURCE_DC_SHAPE					0
#define KE24XX_SOURCE_PULSE_SHAPE				1

// Sweeps defines

#define KE24XX_SWEEP_SPACING_LINEAR				0						
#define KE24XX_SWEEP_SPACING_LOG				1

#define KE24XX_SWEEP_DIR_UP						0						
#define KE24XX_SWEEP_DIR_DOWN					1

#define KE24XX_SWEEP_RANGING_BEST				0						
#define KE24XX_SWEEP_RANGING_AUTO				1
#define KE24XX_SWEEP_RANGING_FIXED				2						

// Triggers

#define KE24XX_TRIG_ON_IMMEDIATE				0						
#define KE24XX_TRIG_ON_TIMER					1
#define KE24XX_TRIG_ON_FRONT_PANEL				2
#define KE24XX_TRIG_ON_GET						3
#define KE24XX_TRIG_ON_TLINK					4
#define KE24XX_TRIG_ON_SOT_LOW					5
#define KE24XX_TRIG_ON_SOT_HIGH					6
#define KE24XX_TRIG_ON_SOT						7

#define KE24XX_TLINK_LINE_1						1
#define KE24XX_TLINK_LINE_2						2
#define KE24XX_TLINK_LINE_3						3
#define KE24XX_TLINK_LINE_4						4

#define KE24XX_TLINK_DIR_SOURCE					0
#define KE24XX_TLINK_DIR_ACCEPT					1

#define KE24XX_ARM_OUT_NEVER					0x00
#define KE24XX_ARM_OUT_ENTER					0x01
#define KE24XX_ARM_OUT_EXIT						0x02

#define KE24XX_TRG_IN_OUT_NEVER					0x00
#define KE24XX_TRG_IN_OUT_SOURCE				0x01
#define KE24XX_TRG_IN_OUT_DELAY					0x02
#define KE24XX_TRG_IN_OUT_MEAS					0x04

// Buffer

#define KE24XX_BUF_TSTMODE_ABS					0
#define KE24XX_BUF_TSTMODE_DELTA				1

// Readings Elements

#define KE24XX_READ_VOLTAGE						0x01
#define KE24XX_READ_CURRENT						0x02
#define KE24XX_READ_RESISTANCE					0x04
#define KE24XX_READ_TIME						0x08

// Digital output Bit 4 Function

#define KE24XX_DIGOUT_BIT4_NORMAL				0						
#define KE24XX_DIGOUT_BIT4_EOT					1
#define KE24XX_DIGOUT_BIT4_BUSY					2

// Hi LEvel Speed constants

#define KE24XX_SLOW_SPEED						0						
#define KE24XX_MEDIUM_SPEED						1
#define KE24XX_FAST_SPEED						2

// list of attributes this driver supports
#define KE24XX_ATTR_SUPPORTED_INSTRUMENT_MODELS		0x1

/*****************************************************************************/
/*= Instrument Specific Error/Warning Codes Here ============================*/
/*****************************************************************************/

// _VI_ERROR = 0x80000000

#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)

#define VI_INSTR_WARNING_OFFSET                 (0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

//VI_INSTR_ERROR_OFFSET = 0xBFFC0900
#define KE24XX_DEVICE_ERROR						(VI_INSTR_ERROR_OFFSET+0x00001000L)
#define KE2430_CONC_NOT_ALLOWED					(VI_INSTR_ERROR_OFFSET+0x00001001L)  
#define KE2430_OFF_MODE_NOT_ALLOWED				(VI_INSTR_ERROR_OFFSET+0x00001002L)    
#define KE24XX_UNSUPPORTED_DEVICE				(VI_INSTR_ERROR_OFFSET+0x00001003L)    
#define KE24XX_UNSUPPORTED_RANGE				(VI_INSTR_ERROR_OFFSET+0x00001004L)    
#define KE24XX_INVALID_NPLC						(VI_INSTR_ERROR_OFFSET+0x00001005L)    
#define KE2430_AUTORANGE_NOT_ALLOWED			(VI_INSTR_ERROR_OFFSET+0x00001006L)    
#define KE2430_OCOM_NOT_ALLOWED					(VI_INSTR_ERROR_OFFSET+0x00001007L)    
#define KE2430_FILTER_NOT_ALLOWED				(VI_INSTR_ERROR_OFFSET+0x00001008L)  
#define KE24XX_CONC_NOT_ENABLED				    (VI_INSTR_ERROR_OFFSET+0x00001009L)  
#define KE2430_IGNORED_COMMAND 				    (VI_INSTR_ERROR_OFFSET+0x0000100AL)    
#define KE24XX_NOT_A_2430					    (VI_INSTR_ERROR_OFFSET+0x0000100BL)  
#define KE24XX_UNSUPPORTED_SOURCE_FUNC		    (VI_INSTR_ERROR_OFFSET+0x0000100CL)  
#define KE24XX_SWEEP_START_STOP				    (VI_INSTR_ERROR_OFFSET+0x0000100DL)  
#define KE24XX_NOT_ENOUGH_MEMORY			    (VI_INSTR_ERROR_OFFSET+0x0000100EL)  
#define KE24XX_READ_ERROR					    (VI_INSTR_ERROR_OFFSET+0x0000100FL) 
#define KE24XX_BAD_RANGE_TABLE_POINTER			(VI_INSTR_ERROR_OFFSET+0x00001010L) 
#define KE24XX_ERROR_CREATING_LIST				(VI_INSTR_ERROR_OFFSET+0x00001011L) 
#define KE24XX_UNSUPPORTED_COMM_TYPE		    (VI_INSTR_ERROR_OFFSET+0x00001012L) 


/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/



ViStatus CVIFUNC Ke24xx_init (ViRsrc resourceName, 
							  ViPInt32 Model,
                    		  ViPSession instrSession);
ViStatus CVIFUNC Ke24xx_close (ViSession instrSession);

ViStatus _VI_FUNC Ke24xx_GetSRQ (ViSession instrumentHandle,
                                 ViBoolean *SRQStatus);

ViStatus _VI_FUNC Ke24xx_Spoll (ViSession instrumentHandle, ViInt32 *statusByte);

ViStatus _VI_FUNC Ke24xx_QueryInterlockTripped (ViSession instrumentHandle,
                                                ViBoolean *interlockStatus);

ViStatus CVIFUNC Ke24xx_reset (ViSession instrSession);

ViStatus _VI_FUNC Ke24xx_self_test (ViSession instrumentHandle,
                                    ViInt32 *selfTestResult);

ViStatus CVIFUNC Ke24xx_error_query (ViSession instrSession, 
									 ViPInt32 errorCode,
                    				 ViChar _VI_FAR errorMessage[]);

//ViStatus CVIFUNC Ke24xx_error_query (ViSession instrSession);

ViStatus CVIFUNC Ke24xx_error_message (ViSession instrSession, 
									   ViStatus statusCode,
                    				   ViChar _VI_FAR message[]);
                    				   
ViStatus CVIFUNC Ke24xx_GetLastError (ViSession instrSession,
									  ViStatus *statusCode,
                    				  ViChar _VI_FAR message[]);
                    				   
ViStatus CVIFUNC Ke24xx_revision_query (ViSession instrSession,
                    					ViChar _VI_FAR driverRev[], 
                    					ViChar _VI_FAR instrRev[]);

ViStatus CVIFUNC Ke24xx_ClearErrorQueue (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_SaveSetup (ViSession instrumentHandle,
                                   ViInt32 setupNumber);

ViStatus CVIFUNC Ke24xx_RecallSetup (ViSession instrumentHandle,
                                     ViInt32 setupNumber);

ViStatus CVIFUNC Ke24xx_SelectPOSetup (ViSession instrumentHandle,
                                       ViInt32 setupNumber);

ViStatus CVIFUNC Ke24xx_EnableRemoteSensing (ViSession instrumentHandle,
                                             ViBoolean status);

ViStatus CVIFUNC Ke24xx_SelectGuardType (ViSession instrumentHandle,
                                         ViInt32 type);

ViStatus CVIFUNC Ke24xx_EnableBeeper (ViSession instrumentHandle,
                                      ViBoolean status);

ViStatus CVIFUNC Ke24xx_EnableAutoZero (ViSession instrumentHandle,
                                        ViBoolean status);

ViStatus CVIFUNC Ke24xx_SelectLineFrequency (ViSession instrumentHandle,
                                             ViInt32 frequency);

ViStatus CVIFUNC Ke24xx_SelectTerminals (ViSession instrumentHandle,
                                         ViInt32 terminals);

ViStatus CVIFUNC Ke24xx_SetAutoRangeChangeMode (ViSession instrumentHandle, ViInt32 type);

ViStatus CVIFUNC Ke24xx_EnableAutoTimestampReset (ViSession instrumentHandle,
                                                  ViBoolean status);

ViStatus CVIFUNC Ke24xx_ResetTimestamp (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_ResetBatteryBackRAM (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_WriteRegister (ViSession instrumentHandle, ViInt32 Register,
                                       ViInt32 value);

ViStatus CVIFUNC Ke24xx_ReadRegister (ViSession instrumentHandle, ViInt32 Register,
                                      ViInt32 *value);

ViStatus CVIFUNC Ke24xx_ClearEnableRegisters (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_ClearEventRegisters (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_ConfigureSRQEvents (ViSession instrumentHandle,
                                            ViUInt32 condition);

ViStatus CVIFUNC Ke24xx_EnableOPC (ViSession instrumentHandle);

ViStatus _VI_FUNC Ke24xx_EnableDisplayMessage (ViSession instrumentHandle,
                                               ViInt32 window, ViInt32 mode,
                                               ViChar message[]);

ViStatus CVIFUNC Ke24xx_GetOPC (ViSession instrumentHandle, ViBoolean *value);

ViStatus CVIFUNC Ke24xx_EnableDisplay (ViSession instrumentHandle,
                                       ViBoolean status);

ViStatus CVIFUNC Ke24xx_ConfigureDisplayResolution (ViSession instrumentHandle,ViInt32 Resolution);

ViStatus CVIFUNC Ke24xx_ConfigureSourceMode (ViSession instrumentHandle,
                                         ViInt32 function, ViInt32 mode,
                                         ViInt32 shape, ViInt32 range);

ViStatus CVIFUNC Ke24xx_ConfigureSourceDelay (ViSession instrumentHandle,
                                              ViBoolean Auto, double delay);

ViStatus CVIFUNC Ke24xx_ConfigurePulse (ViSession instrumentHandle, double width, double delay);

ViStatus CVIFUNC Ke24xx_ConfigureSourceCompliance (ViSession instrumentHandle,
                                                   ViInt32 sourceFunction, double level);

ViStatus CVIFUNC Ke24xx_ConfigureVSourceProtection (ViSession instrumentHandle,
                                                    double level);

ViStatus CVIFUNC Ke24xx_ConfigureSourceLevel (ViSession instrumentHandle,
                                              ViInt32 sourceFunction, double level,
                                              ViInt32 update);


ViStatus CVIFUNC Ke24xx_ConfigureSourceSweep (ViSession instrumentHandle,
                                     		  ViInt32 sourceFunction, ViInt32 spacing,
                                     		  ViInt32 direction, ViInt32 ranging,
                                     		  double start, double stop,
                                     		  ViInt32 numberofPoints);

ViStatus CVIFUNC Ke24xx_ConfigureSourceList (ViSession instrumentHandle,
                                    		 ViInt32 sourceFunction,
                                    		 ViInt32 numberOfPoints, double values[]);

ViStatus CVIFUNC Ke24xx_UseMemorySweepMode (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_SaveMemSweepPoint (ViSession instrumentHandle,
                                           ViInt32 location);

ViStatus CVIFUNC Ke24xx_RecallMemSweepPoint (ViSession instrumentHandle,
                                             ViInt32 location);

ViStatus CVIFUNC Ke24xx_EnableInterlock (ViSession instrumentHandle,
                                         ViBoolean status);

ViStatus CVIFUNC Ke24xx_ConfigureOutputOffMode (ViSession instrumentHandle,
                                                ViInt32 mode);

ViStatus CVIFUNC Ke24xx_EnableSourceAutoClear (ViSession instrumentHandle,
                                               ViBoolean status);

ViStatus CVIFUNC Ke24xx_EnableSourceOutput (ViSession instrumentHandle,
                                            ViBoolean status);

ViStatus CVIFUNC Ke24xx_EnableConcurrent (ViSession instrumentHandle,
                                          ViBoolean status);

ViStatus CVIFUNC Ke24xx_SelectSenseFunc (ViSession instrumentHandle,
                                         ViBoolean DCV, ViBoolean DCI,
                                         ViBoolean RES);

ViStatus CVIFUNC Ke24xx_ConfigureDCVSense (ViSession instrumentHandle, ViInt32 range,
                                       	   double NPLC);

ViStatus CVIFUNC Ke24xx_ConfigureDCISense (ViSession instrumentHandle, ViInt32 range,
                                       	   double NPLC);

ViStatus CVIFUNC Ke24xx_ConfigureRESSense (ViSession instrumentHandle, ViInt32 range,
                                       	   double NPLC, ViInt32 mode,
                                       	   ViBoolean compensation);

ViStatus CVIFUNC Ke24xx_ConfigureFilter (ViSession instrumentHandle, ViInt32 type,
                              	         ViInt32 weight);

ViStatus CVIFUNC Ke24xx_EnableFilter (ViSession instrumentHandle,
                                      ViBoolean status);

ViStatus CVIFUNC Ke24xx_ConfigureArmLayer (ViSession instrumentHandle, 
									   	   ViInt32 count,
                                       	   ViInt32 triggerSource, 
                                       	   double timer,
                                       	   ViInt32 triggerLinkDirection,
                                       	   ViInt32 triggerLinkInputLine,
                                       	   ViInt32 triggerLinkOutputLine,
                                       	   ViInt32 outputOn);

ViStatus CVIFUNC Ke24xx_ConfigureTriggerLayer (ViSession instrumentHandle,
                                 	           ViInt32 count, 
                                     	       ViInt32 triggerSource,
                                         	   double delay,
                                           	   ViInt32 triggerLinkDirection,
                                           	   ViInt32 triggerLinkInputLine,
                                           	   ViInt32 inputOn,
                                           	   ViInt32 triggerLinkOutputLine,
                                           	   ViInt32 outputOn);

ViStatus CVIFUNC Ke24xx_Initiate (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_Abort (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_ClearTriggers (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_ClearBuffer (ViSession instrumentHandle);

ViStatus CVIFUNC Ke24xx_ConfigureBuffer (ViSession instrumentHandle,
                                     	 ViInt32 bufferSize, ViInt32 timeStampFormat);

ViStatus CVIFUNC Ke24xx_EnableBuffer (ViSession instrumentHandle,
                                      ViBoolean status);

ViStatus CVIFUNC Ke24xx_Fetch (ViSession instrumentHandle, ViInt32 elements,
                               ViInt32 *numberOfReadings, float values[]);

ViStatus CVIFUNC Ke24xx_Read (ViSession instrumentHandle, ViInt32 elements,
                              ViInt32 *numberOfReadings, float values[]);

ViStatus CVIFUNC Ke24xx_ReadBuffer (ViSession instrumentHandle, ViInt32 elements,
                                    ViInt32 *numberOfReadings, float values[]);

ViStatus CVIFUNC Ke24xx_ConfigureDigitalOutput (ViSession instrumentHandle,
                                      			ViInt32 bit4Function,
                                      			ViInt32 EOT_BUSY_Polarity);

ViStatus CVIFUNC Ke24xx_SetDigitalOutput (ViSession instrumentHandle, ViInt32 value);


ViStatus _VI_FUNC Ke24xx_WriteInstrData (ViSession instrumentHandle,
                                         ViChar command_to_send[]);

   
ViStatus _VI_FUNC Ke24xx_ReadInstrData (ViSession vi, ViInt32 numBytes, 
                                        ViChar rdBuf[], ViInt32 *bytesRead);


ViStatus CVIFUNC Ke24xx_Configure_DC_IV (ViSession instrumentHandle,
                                       ViInt32 sourceRange,
                                       double sourceCompliance,
                                       ViInt32 senseRange,
                                       double sourceLevel,
                                       ViInt32 speed);

ViStatus CVIFUNC Ke24xx_Perform_DC_IV (ViSession instrumentHandle, ViInt32 sourceRange,
                               double sourceCompliance, double sourceLevel,
                               ViInt32 senseRange, ViInt32 speed,
                               float reading[]);


ViStatus CVIFUNC Ke24xx_Configure_DC_VI (ViSession instrumentHandle,
                                       ViInt32 sourceRange,
                                       double sourceCompliance,
                                       double sourceProtection, double sourceLevel,
                                       ViInt32 senseRange, ViInt32 speed);

ViStatus CVIFUNC Ke24xx_Perform_DC_VI (ViSession instrumentHandle,
                                       ViInt32 sourceRange,
                                       double sourceCompliance,
                                       double sourceProtection,
                                       double sourceLevel,    
                                       ViInt32 senseRange, 
                                       ViInt32 speed,
                                       float reading[]);

ViStatus CVIFUNC Ke24xx_Configure_Sweep_IV (ViSession instrumentHandle,
                                          ViInt32 ranging, ViInt32 spacing,
                                          ViInt32 direction,
                                          double sourceCompliance, double start,
                                          double stop, ViInt32 numberofPoints,
                                          ViInt32 senseRange, ViInt32 speed);

ViStatus CVIFUNC Ke24xx_Perform_Sweep_IV (ViSession instrumentHandle,
                                          ViInt32 ranging, ViInt32 spacing,
                                          ViInt32 direction,
                                          double sourceCompliance, double start,
                                          double stop, ViInt32 numberofPoints,
                                          ViInt32 senseRange, ViInt32 speed,
                                          float reading[]);

ViStatus CVIFUNC Ke24xx_Configure_Sweep_VI (ViSession instrumentHandle,
                                          ViInt32 ranging, ViInt32 spacing,
                                          ViInt32 direction,
                                          double sourceCompliance, 
                                          double sourceProtection,
                                          double start,
                                          double stop, ViInt32 numberofPoints,
                                          ViInt32 senseRange, ViInt32 speed);

ViStatus CVIFUNC Ke24xx_Perform_Sweep_VI (ViSession instrumentHandle,
                                          ViInt32 ranging, ViInt32 spacing,
                                          ViInt32 direction,
                                          double sourceCompliance, 
                                          double sourceProtection,
                                          double start,
                                          double stop, ViInt32 numberofPoints,
                                          ViInt32 senseRange, ViInt32 speed,
                                          float reading[]);

ViStatus CVIFUNC Ke24xx_Configure_List_IV (ViSession instrumentHandle,
                                         ViInt32 numberOfPoints, 
                                         double values[],
                                         double sourceCompliance, 
                                         ViInt32 senseRange, 
                                         ViInt32 speed);

ViStatus CVIFUNC Ke24xx_Perform_List_IV (ViSession instrumentHandle,
                                         ViInt32 numberOfPoints,
                                         double values[], 
                                         double sourceCompliance, 
                                         ViInt32 senseRange, 
                                         ViInt32 speed, 
                                         float reading[]);

ViStatus CVIFUNC Ke24xx_Configure_List_VI (ViSession instrumentHandle,
                                         ViInt32 numberOfPoints, 
                                         double values[],
                                         double sourceCompliance, 
                                         double sourceProtection,
                                         ViInt32 senseRange,
                                         ViInt32 speed);

ViStatus CVIFUNC Ke24xx_Perform_List_VI (ViSession instrumentHandle,
                                         ViInt32 numberOfPoints, 
                                         double values[],
                                         double sourceCompliance, 
                                         double sourceProtection,
                                         ViInt32 senseRange, 
                                         ViInt32 speed, 
                                         float reading[]);

extern ViStatus CVIFUNC KEGetSupportedModels (ViString *pModels);




#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif

